{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#gatk_haplotypecaller_cram.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/gatk:4.0.3.0"
                }
            ],
            "baseCommand": [
                "/gatk"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "--java-options \"-Xms2000m\" PrintReads -R $(inputs.reference.path) -I $(inputs.input_cram.path) --interval-padding 500 -L $(inputs.interval_list.path) -O local.sharded.bam && /gatk --java-options \"-Xms8000m -XX:GCTimeLimit=50 -XX:GCHeapFreeLimit=10\" HaplotypeCaller -R $(inputs.reference.path) -O $(inputs.input_cram.nameroot).vcf.gz -I local.sharded.bam -L $(inputs.interval_list.path) -ERC GVCF --max-alternate-alleles 3 -contamination $(inputs.contamination) --read-filter OverclippedReadFilter"
                }
            ],
            "inputs": [
                {
                    "type": "float",
                    "id": "#gatk_haplotypecaller_cram.cwl/gatk_haplotypecaller/contamination"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.cram.crai"
                    ],
                    "id": "#gatk_haplotypecaller_cram.cwl/gatk_haplotypecaller/input_cram"
                },
                {
                    "type": "File",
                    "id": "#gatk_haplotypecaller_cram.cwl/gatk_haplotypecaller/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#gatk_haplotypecaller_cram.cwl/gatk_haplotypecaller/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller_cram.cwl/gatk_haplotypecaller/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_collectgvcfcallingmetrics.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 3000,
                    "coresMin": 16
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.18.2-dev"
                }
            ],
            "baseCommand": [
                "java",
                "-Xms2000m",
                "-jar",
                "/picard.jar",
                "CollectVariantCallingMetrics"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "INPUT=$(inputs.input_vcf.path) OUTPUT=$(inputs.final_gvcf_base_name) DBSNP=$(inputs.dbsnp_vcf.path) SEQUENCE_DICTIONARY=$(inputs.reference_dict.path) TARGET_INTERVALS=$(inputs.wgs_evaluation_interval_list.path) GVCF_INPUT=true THREAD_COUNT=16"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/dbsnp_vcf"
                },
                {
                    "type": "string",
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/final_gvcf_base_name"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/input_vcf"
                },
                {
                    "type": "File",
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/reference_dict"
                },
                {
                    "type": "File",
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/wgs_evaluation_interval_list"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_metrics"
                    },
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_intervallisttools.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.18.2-dev"
                }
            ],
            "baseCommand": [
                "java",
                "-Xmx2000m",
                "-jar",
                "/picard.jar"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "IntervalListTools SCATTER_COUNT=50 SUBDIVISION_MODE=BALANCING_WITHOUT_INTERVAL_SUBDIVISION_WITH_OVERFLOW UNIQUE=true SORT=true BREAK_BANDS_AT_MULTIPLES_OF=1000000 INPUT=$(inputs.interval_list.path) OUTPUT=$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#picard_intervallisttools.cwl/picard_intervallisttools/interval_list"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "temp*/*.interval_list"
                    },
                    "id": "#picard_intervallisttools.cwl/picard_intervallisttools/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_mergevcfs_python_renamesample.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 3000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.18.9"
                }
            ],
            "baseCommand": [
                "java",
                "-Xms2000m",
                "-jar",
                "/picard.jar",
                "MergeVcfs"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "OUTPUT=/dev/stdout CREATE_INDEX=false | /VcfSampleRename.py $(inputs.biospecimen_name) | bgzip -c  > $(inputs.output_vcf_basename).g.vcf.gz && tabix -p vcf $(inputs.output_vcf_basename).g.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#picard_mergevcfs_python_renamesample.cwl/picard_mergevcfs_python_renamesample/biospecimen_name"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "INPUT=",
                            "separate": false
                        }
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_mergevcfs_python_renamesample.cwl/picard_mergevcfs_python_renamesample/input_vcf"
                },
                {
                    "type": "string",
                    "id": "#picard_mergevcfs_python_renamesample.cwl/picard_mergevcfs_python_renamesample/output_vcf_basename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_mergevcfs_python_renamesample.cwl/picard_mergevcfs_python_renamesample/output"
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#main",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/biospecimen_name"
                },
                {
                    "type": "float",
                    "id": "#main/contamination"
                },
                {
                    "type": "File",
                    "id": "#main/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "id": "#main/indexed_reference_fasta"
                },
                {
                    "type": "File",
                    "id": "#main/input_cram"
                },
                {
                    "type": "string",
                    "id": "#main/output_basename"
                },
                {
                    "type": "File",
                    "id": "#main/reference_dict"
                },
                {
                    "type": "File",
                    "id": "#main/wgs_calling_interval_list"
                },
                {
                    "type": "File",
                    "id": "#main/wgs_evaluation_interval_list"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/picard_mergevcfs_python_renamesample/output",
                    "id": "#main/gvcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/picard_collectgvcfcallingmetrics/output",
                    "id": "#main/gvcf_calling_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#gatk_haplotypecaller_cram.cwl",
                    "in": [
                        {
                            "source": "#main/contamination",
                            "id": "#main/gatk_haplotypecaller/contamination"
                        },
                        {
                            "source": "#main/input_cram",
                            "id": "#main/gatk_haplotypecaller/input_cram"
                        },
                        {
                            "source": "#main/picard_intervallisttools/output",
                            "id": "#main/gatk_haplotypecaller/interval_list"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/gatk_haplotypecaller/reference"
                        }
                    ],
                    "scatter": [
                        "#main/gatk_haplotypecaller/interval_list"
                    ],
                    "out": [
                        "#main/gatk_haplotypecaller/output"
                    ],
                    "id": "#main/gatk_haplotypecaller"
                },
                {
                    "run": "#picard_collectgvcfcallingmetrics.cwl",
                    "in": [
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/picard_collectgvcfcallingmetrics/dbsnp_vcf"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/picard_collectgvcfcallingmetrics/final_gvcf_base_name"
                        },
                        {
                            "source": "#main/picard_mergevcfs_python_renamesample/output",
                            "id": "#main/picard_collectgvcfcallingmetrics/input_vcf"
                        },
                        {
                            "source": "#main/reference_dict",
                            "id": "#main/picard_collectgvcfcallingmetrics/reference_dict"
                        },
                        {
                            "source": "#main/wgs_evaluation_interval_list",
                            "id": "#main/picard_collectgvcfcallingmetrics/wgs_evaluation_interval_list"
                        }
                    ],
                    "out": [
                        "#main/picard_collectgvcfcallingmetrics/output"
                    ],
                    "id": "#main/picard_collectgvcfcallingmetrics"
                },
                {
                    "run": "#picard_intervallisttools.cwl",
                    "in": [
                        {
                            "source": "#main/wgs_calling_interval_list",
                            "id": "#main/picard_intervallisttools/interval_list"
                        }
                    ],
                    "out": [
                        "#main/picard_intervallisttools/output"
                    ],
                    "id": "#main/picard_intervallisttools"
                },
                {
                    "run": "#picard_mergevcfs_python_renamesample.cwl",
                    "in": [
                        {
                            "source": "#main/biospecimen_name",
                            "id": "#main/picard_mergevcfs_python_renamesample/biospecimen_name"
                        },
                        {
                            "source": "#main/gatk_haplotypecaller/output",
                            "id": "#main/picard_mergevcfs_python_renamesample/input_vcf"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/picard_mergevcfs_python_renamesample/output_vcf_basename"
                        }
                    ],
                    "out": [
                        "#main/picard_mergevcfs_python_renamesample/output"
                    ],
                    "id": "#main/picard_mergevcfs_python_renamesample"
                }
            ],
            "hints": [
                {
                    "class": "https://sevenbridges.comAWSInstanceType",
                    "value": "c4.8xlarge;ebs-gp2;850"
                },
                {
                    "class": "https://sevenbridges.commaxNumberOfParallelInstances",
                    "value": 4
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "sbg": "https://sevenbridges.com"
    }
}
